package com.qianhe.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.qianhe.common.annotation.Log;
import com.qianhe.common.core.controller.BaseController;
import com.qianhe.common.core.domain.AjaxResult;
import com.qianhe.common.enums.BusinessType;
import com.qianhe.domain.WorkJd;
import com.qianhe.service.IWorkJdService;
import com.qianhe.common.utils.poi.ExcelUtil;
import com.qianhe.common.core.page.TableDataInfo;

/**
 * 节点Controller
 *
 * @author qianhe
 * @date 2024-01-17
 */
@RestController
@RequestMapping("/work/jd")
public class WorkJdController extends BaseController
{
    @Autowired
    private IWorkJdService workJdService;

    /**
     * 查询节点列表
     */
    @GetMapping("/list")
    public TableDataInfo list(WorkJd workJd)
    {
        startPage();
        List<WorkJd> list = workJdService.selectWorkJdList(workJd);
        return getDataTable(list);
    }

    /**
     * 导出节点列表
     */
    @Log(title = "节点", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WorkJd workJd)
    {
        List<WorkJd> list = workJdService.selectWorkJdList(workJd);
        ExcelUtil<WorkJd> util = new ExcelUtil<WorkJd>(WorkJd.class);
        util.exportExcel(response, list, "节点数据");
    }

    /**
     * 获取节点详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(workJdService.selectWorkJdById(id));
    }

    /**
     * 新增节点
     */
    @Log(title = "节点", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WorkJd workJd)
    {
        return toAjax(workJdService.insertWorkJd(workJd));
    }

    /**
     * 修改节点
     */
    @Log(title = "节点", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WorkJd workJd)
    {
        return toAjax(workJdService.updateWorkJd(workJd));
    }

    /**
     * 删除节点
     */
    @Log(title = "节点", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(workJdService.deleteWorkJdByIds(ids));
    }

    /**
     * 用户下拉框
     */
    @GetMapping("/getUserList")
    public AjaxResult getUserList(){
        return AjaxResult.success(workJdService.getUserList());
    }

}
