package com.qianhe.controller;

import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.qianhe.domain.WorkXmcb;
import com.qianhe.service.IWorkXmcbService;
import com.qianhe.vo.WorkXmTjVo;
import com.qianhe.vo.WorkXmVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.qianhe.common.annotation.Log;
import com.qianhe.common.core.controller.BaseController;
import com.qianhe.common.core.domain.AjaxResult;
import com.qianhe.common.enums.BusinessType;
import com.qianhe.domain.WorkXm;
import com.qianhe.service.IWorkXmService;
import com.qianhe.common.utils.poi.ExcelUtil;
import com.qianhe.common.core.page.TableDataInfo;

/**
 * 项目Controller
 *
 * @author qianhe
 * @date 2024-01-17
 */
@RestController
@RequestMapping("/work/xm")
public class WorkXmController extends BaseController
{
    @Autowired
    private IWorkXmService workXmService;
    @Autowired
    private IWorkXmcbService workXmcbService;

    /**
     * 查询项目列表
     */
    @GetMapping("/list")
    public TableDataInfo list(WorkXm workXm)
    {
        startPage();
        List<WorkXm> list = workXmService.selectWorkXmList(workXm);
        return getDataTable(list);
    }

    /**
     * 导出项目列表
     */
    @Log(title = "项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WorkXm workXm)
    {
        List<WorkXm> list = workXmService.selectWorkXmList(workXm);
        ExcelUtil<WorkXm> util = new ExcelUtil<WorkXm>(WorkXm.class);
        util.exportExcel(response, list, "项目数据");
    }

    /**
     * 获取项目详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(workXmService.selectWorkXmById(id));
    }

    /**
     * 新增项目
     */
    @Log(title = "项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WorkXm workXm)
    {
        return toAjax(workXmService.insertWorkXm(workXm));
    }

    /**
     * 修改项目
     */
    @Log(title = "项目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WorkXm workXm)
    {
        return toAjax(workXmService.updateWorkXm(workXm));
    }

    /**
     * 删除项目
     */
    @Log(title = "项目", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(workXmService.deleteWorkXmByIds(ids));
    }

    /**
     * 提交
     */
    @PutMapping("/submit/{id}")
    public AjaxResult submit(@PathVariable Long id){
        WorkXm workXm = new WorkXm();
        workXm.setId(id);
        return toAjax(workXmService.submit(workXm));
    }

    /**
     * 项目进度查询列表
     */
    @GetMapping("/getXmJdList")
    public TableDataInfo getXmJdList(WorkXm workXm){
        //查询已提交的项目
        workXm.setTjzt("1");
        startPage();
        List<WorkXm> list = workXmService.selectWorkXmList(workXm);
        return getDataTable(list);
    }

    /**
     * 查询进度（分为三块，一块为项目信息，一块为审批历史，一块为进度查看）
     */
    @GetMapping("/xmjd/{id}")
    public AjaxResult getXmInfo(@PathVariable("id") Long id){
        AjaxResult ajaxResult = AjaxResult.success();
        SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        //查询项目详情
        WorkXmVo workXmVo = workXmService.getXmInfo(id);
        //查询审批历史
        List<WorkXmcb> workXmcbs = workXmcbService.getspls(id);
        ajaxResult.put("spls",workXmcbs);
        //根究审核人类型去重
        ArrayList<WorkXmcb> collect = workXmcbs.stream().collect(Collectors
                .collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator
                        .comparing(WorkXmcb::getShrlx))), ArrayList::new));
        List<Map<String,Object>> list = new ArrayList<>();
        for (WorkXmcb workXmcb : collect) {
            Map<String,Object> map = new HashMap<>();
            switch (workXmcb.getShrlx()){
                case "0":
                    map.put("jd","压裂通知");
                    break;
                case "1":
                    map.put("jd","采集设计");
                    break;
                case "2":
                    if (workXmcb.getShzt().equals("同意")){
                        map.put("jd","设计审核");
                        break;
                    }
                    break;
                case "3":
                    if (workXmcb.getShzt().equals("符合条件")){
                        map.put("jd","现场勘查");
                        break;
                    }
                    break;
                default:
                    map.put("jd","");
                    break;
            }
            map.put("shsj",dateFormat.format(workXmcb.getShsj()));
            list.add(map);
        }
        ajaxResult.put("workXm",workXmVo);
//        ajaxResult.put("spls",workXmcbs);
        ajaxResult.put("jdck",list);
        return ajaxResult;
    }

    /**
     * 工作量统计
     */
    @GetMapping("/getGzlTjList")
    public TableDataInfo getGzlTjList(WorkXmVo workXmVo){

        //查询所有已提交的项目
        workXmVo.setTjzt("1");
        startPage();
        List<WorkXm> workXms = workXmService.selectWorkXmGzlList(workXmVo);
        //查询所有审批历史
        List<WorkXmcb> workXmcbs = workXmcbService.selectWorkXmcbList(new WorkXmcb());
        List<WorkXmTjVo> list = new ArrayList<>();
        for (WorkXm xm : workXms) {
            WorkXmTjVo workXmTjVo1 = new WorkXmTjVo();
            workXmTjVo1.setJh(xm.getJh());
            for (WorkXmcb workXmcb : workXmcbs) {
                if (xm.getId().equals(workXmcb.getYltzId())){
                    switch (workXmcb.getShrlx()){
                        case "0":
                            workXmTjVo1.setYltz(workXmcb.getShr());
                            break;
                        case "1":
                            workXmTjVo1.setCjsj(workXmcb.getShr());
                            break;
                        case "2":
                            workXmTjVo1.setSjsh(workXmcb.getShr());
                            break;
                        case "3":
                            workXmTjVo1.setXckc(workXmcb.getShr());
                            break;
                        default:break;
                    }
                }
            }
            list.add(workXmTjVo1);
        }
        return getDataTable(list);

//        startPage();
//        List<WorkXmTjVo> list = workXmService.getGzlTjList(workXmVo);
//        return getDataTable(list);
    }

    /**
     * 导出工作量统计
     */
    @Log(title = "工作量", businessType = BusinessType.EXPORT)
    @PostMapping("/exportGzl")
    public void exportGzl(HttpServletResponse response, WorkXmVo workXmVo)
    {
        List<WorkXmTjVo> list = workXmService.getGzlTjList(workXmVo);
        ExcelUtil<WorkXmTjVo> util = new ExcelUtil<WorkXmTjVo>(WorkXmTjVo.class);
        util.exportExcel(response, list, "工作量统计");
    }

    /**
     * 查询采集设计列表
     */
    @GetMapping("/getCjsjList")
    public TableDataInfo getCjsjList(WorkXm workXm){
        //查询压裂通知已提交的项目
        workXm.setTjzt("1");
        startPage();
        List<WorkXm> workXms = workXmService.selectWorkXmList(workXm);
        return getDataTable(workXms);
    }

    /**
     * 上传采集设计附件
     */
    @Log(title = "项目", businessType = BusinessType.UPDATE)
    @PutMapping("/updateFile")
    public AjaxResult updateFile(@RequestBody WorkXmVo workXmVo)
    {
        return toAjax(workXmService.updateFile(workXmVo));
    }

    /**
     * 提交采集设计
     */
    @PostMapping("/submitCjsj/{id}")
    public AjaxResult submitCjsj(@PathVariable Long id){
        WorkXm workXm = new WorkXm();
        workXm.setId(id);
        return toAjax(workXmService.submitCjsj(workXm));
    }
}
