package com.qianhe.controller;

import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.qianhe.common.utils.SecurityUtils;
import com.qianhe.service.IWorkJdService;
import com.qianhe.service.IWorkXmService;
import com.qianhe.vo.WorkXmVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.qianhe.common.annotation.Log;
import com.qianhe.common.core.controller.BaseController;
import com.qianhe.common.core.domain.AjaxResult;
import com.qianhe.common.enums.BusinessType;
import com.qianhe.domain.WorkXmcb;
import com.qianhe.service.IWorkXmcbService;
import com.qianhe.common.utils.poi.ExcelUtil;
import com.qianhe.common.core.page.TableDataInfo;

/**
 * 项目从表Controller
 *
 * @author qianhe
 * @date 2024-01-17
 */
@RestController
@RequestMapping("/work/xmcb")
public class WorkXmcbController extends BaseController
{
    @Autowired
    private IWorkXmcbService workXmcbService;
    @Autowired
    private IWorkXmService workXmService;
    @Autowired
    private IWorkJdService workJdService;

    /**
     * 首页-待办已办
     */
    @GetMapping("/taskList/{state}")
    public TableDataInfo taskList(@PathVariable("state") String state, WorkXmVo workXmVo){

        //当前登录用户id
        Long userId = SecurityUtils.getUserId();
        //查询当前登录用户属于哪个节点的审批人
        List<String> jds = workJdService.selectJdmcByUserId(userId);
        if (jds.size() > 0){
            //根据节点名称和用户id查询待办已办列表
            //查询当前登陆人待办任务
            if (state.equals("0")){
                userId = null;
                startPage();
                return getDataTable(workXmcbService.taskList(userId, state, jds,workXmVo.getJh()));
            }else {
                jds = null;
                startPage();
                return getDataTable(workXmcbService.taskList(userId, state, jds,workXmVo.getJh()));
            }
        }
        return getDataTable(new ArrayList<>());

//        startPage();
//        List<WorkXmVo> list = workXmcbService.taskList(state,workXmVo);
//        return getDataTable(list);
    }

    /**
     * 查询详情（分为两块，一块为项目信息，一块为审批历史）
     */
    @GetMapping("/xm/{id}")
    public AjaxResult getXmInfo(@PathVariable("id") Long id){
        AjaxResult ajaxResult = AjaxResult.success();
        //查询项目详情
        WorkXmVo workXmVo = workXmService.getXmInfo(id);
        //查询审批历史
        List<WorkXmcb> workXmcbs = workXmcbService.getspls(id);
        ajaxResult.put("workXm",workXmVo);
        ajaxResult.put("spls",workXmcbs);
        return ajaxResult;
    }

    /**
     * 办理审核按钮
     */
    @PostMapping("/handle")
    public AjaxResult handle(@RequestBody WorkXmVo workXmVo){
        return toAjax(workXmcbService.handle(workXmVo));
    }

    /**
     * 查询项目从表列表
     */
    @GetMapping("/list")
    public TableDataInfo list(WorkXmcb workXmcb)
    {
        startPage();
        List<WorkXmcb> list = workXmcbService.selectWorkXmcbList(workXmcb);
        return getDataTable(list);
    }

    /**
     * 导出项目从表列表
     */
    @Log(title = "项目从表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WorkXmcb workXmcb)
    {
        List<WorkXmcb> list = workXmcbService.selectWorkXmcbList(workXmcb);
        ExcelUtil<WorkXmcb> util = new ExcelUtil<WorkXmcb>(WorkXmcb.class);
        util.exportExcel(response, list, "项目从表数据");
    }

    /**
     * 获取项目从表详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(workXmcbService.selectWorkXmcbById(id));
    }

    /**
     * 新增项目从表
     */
    @Log(title = "项目从表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WorkXmcb workXmcb)
    {
        return toAjax(workXmcbService.insertWorkXmcb(workXmcb));
    }

    /**
     * 修改项目从表
     */
    @Log(title = "项目从表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WorkXmcb workXmcb)
    {
        return toAjax(workXmcbService.updateWorkXmcb(workXmcb));
    }

    /**
     * 删除项目从表
     */
    @Log(title = "项目从表", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(workXmcbService.deleteWorkXmcbByIds(ids));
    }
}
