package com.qianhe.service.impl;

import java.util.List;
import java.util.Map;

import com.qianhe.common.utils.DateUtils;
import com.qianhe.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.qianhe.mapper.WorkJdMapper;
import com.qianhe.domain.WorkJd;
import com.qianhe.service.IWorkJdService;

/**
 * 节点Service业务层处理
 *
 * @author qianhe
 * @date 2024-01-17
 */
@Service
public class WorkJdServiceImpl implements IWorkJdService
{
    @Autowired
    private WorkJdMapper workJdMapper;

    /**
     * 查询节点
     *
     * @param id 节点主键
     * @return 节点
     */
    @Override
    public WorkJd selectWorkJdById(Long id)
    {
        return workJdMapper.selectWorkJdById(id);
    }

    /**
     * 查询节点列表
     *
     * @param workJd 节点
     * @return 节点
     */
    @Override
    public List<WorkJd> selectWorkJdList(WorkJd workJd)
    {
        return workJdMapper.selectWorkJdList(workJd);
    }

    /**
     * 新增节点
     *
     * @param workJd 节点
     * @return 结果
     */
    @Override
    public int insertWorkJd(WorkJd workJd)
    {
        workJd.setCreateBy(SecurityUtils.getUsername());
        workJd.setCreateTime(DateUtils.getNowDate());
        return workJdMapper.insertWorkJd(workJd);
    }

    /**
     * 修改节点
     *
     * @param workJd 节点
     * @return 结果
     */
    @Override
    public int updateWorkJd(WorkJd workJd)
    {
        workJd.setUpdateBy(SecurityUtils.getUsername());
        workJd.setUpdateTime(DateUtils.getNowDate());
        return workJdMapper.updateWorkJd(workJd);
    }

    /**
     * 批量删除节点
     *
     * @param ids 需要删除的节点主键
     * @return 结果
     */
    @Override
    public int deleteWorkJdByIds(Long[] ids)
    {
        return workJdMapper.deleteWorkJdByIds(ids);
    }

    /**
     * 删除节点信息
     *
     * @param id 节点主键
     * @return 结果
     */
    @Override
    public int deleteWorkJdById(Long id)
    {
        return workJdMapper.deleteWorkJdById(id);
    }

    /**
     * 获取用户下拉框
     * @return
     */
    @Override
    public List<Map<String, Object>> getUserList() {
        return workJdMapper.getUserList();
    }

    @Override
    public List<String> selectJdmcByUserId(Long userId) {
        return workJdMapper.selectJdmcByUserId(userId);
    }
}
