package com.qianhe.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.qianhe.common.exception.ServiceException;
import com.qianhe.common.utils.DateUtils;
import com.qianhe.common.utils.SecurityUtils;
import com.qianhe.common.utils.StringUtils;
import com.qianhe.domain.WorkAccessory;
import com.qianhe.domain.WorkXmcb;
import com.qianhe.mapper.WorkXmcbMapper;
import com.qianhe.service.IWorkXmcbService;
import com.qianhe.vo.WorkXmTjVo;
import com.qianhe.vo.WorkXmVo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.qianhe.mapper.WorkXmMapper;
import com.qianhe.domain.WorkXm;
import com.qianhe.service.IWorkXmService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 项目Service业务层处理
 *
 * @author qianhe
 * @date 2024-01-17
 */
@Service
public class WorkXmServiceImpl implements IWorkXmService
{
    @Autowired
    private WorkXmMapper workXmMapper;
    @Autowired
    private WorkXmcbMapper workXmcbMapper;

    /**
     * 查询项目
     *
     * @param id 项目主键
     * @return 项目
     */
    @Override
    public WorkXm selectWorkXmById(Long id)
    {
        return workXmMapper.selectWorkXmById(id);
    }

    /**
     * 查询项目列表
     *
     * @param workXm 项目
     * @return 项目
     */
    @Override
    public List<WorkXm> selectWorkXmList(WorkXm workXm)
    {
        return workXmMapper.selectWorkXmList(workXm);
    }

    /**
     * 新增项目
     *
     * @param workXm 项目
     * @return 结果
     */
    @Override
    public int insertWorkXm(WorkXm workXm)
    {
        workXm.setTbrId(SecurityUtils.getUserId());
        workXm.setTbsj(DateUtils.getNowDate());
        workXm.setDqjdmc("压裂通知");
        workXm.setCreateBy(SecurityUtils.getUsername());
        workXm.setCreateTime(DateUtils.getNowDate());
        if (StringUtils.isNotEmpty(workXm.getTjzt())){
            if (workXm.getTjzt().equals("1")){
                workXm.setLczt("1");
                workXm.setTjzt("1");
                workXm.setDqjdmc("采集设计");
                int i = workXmMapper.insertWorkXm(workXm);
                //新增操作历史表
                WorkXmcb workXmcb = new WorkXmcb();
                workXmcb.setYltzId(workXm.getId());
                workXmcb.setShrId(SecurityUtils.getUserId());
                workXmcb.setShrlx("0");
                workXmcb.setShsj(DateUtils.getNowDate());
                workXmcb.setWczt("1");
                workXmcb.setSfsctj("1");
                workXmcb.setCreateBy(SecurityUtils.getUsername());
                workXmcb.setCreateTime(DateUtils.getNowDate());
                workXmcbMapper.insertWorkXmcb(workXmcb);
                return i;
            }
        }
        return workXmMapper.insertWorkXm(workXm);
    }

    /**
     * 修改项目
     *
     * @param workXm 项目
     * @return 结果
     */
    @Override
    public int updateWorkXm(WorkXm workXm)
    {
        workXm.setUpdateBy(SecurityUtils.getUsername());
        workXm.setUpdateTime(DateUtils.getNowDate());
        return workXmMapper.updateWorkXm(workXm);
    }

    /**
     * 批量删除项目
     *
     * @param ids 需要删除的项目主键
     * @return 结果
     */
    @Override
    public int deleteWorkXmByIds(Long[] ids)
    {
        //批量删除项目从表信息
        workXmMapper.deleteWorkXmCbByYltzIds(ids);
        return workXmMapper.deleteWorkXmByIds(ids);
    }

    /**
     * 删除项目信息
     *
     * @param id 项目主键
     * @return 结果
     */
    @Override
    public int deleteWorkXmById(Long id)
    {
        return workXmMapper.deleteWorkXmById(id);
    }

    /**
     * 提交
     * @param workXm
     * @return
     */
    @Override
    @Transactional
    public int submit(WorkXm workXm) {
        workXm.setLczt("1");
        workXm.setTjzt("1");
        workXm.setDqjdmc("采集设计");
        int i = workXmMapper.updateWorkXm(workXm);
        //新增操作历史表
        WorkXmcb workXmcb = new WorkXmcb();
        workXmcb.setYltzId(workXm.getId());
        workXmcb.setShrId(SecurityUtils.getUserId());
        workXmcb.setShrlx("0");
        workXmcb.setShsj(DateUtils.getNowDate());
        workXmcb.setWczt("1");
        workXmcb.setSfsctj("1");
        workXmcb.setCreateBy(SecurityUtils.getUsername());
        workXmcb.setCreateTime(DateUtils.getNowDate());
        workXmcbMapper.insertWorkXmcb(workXmcb);
        return i;
    }

    /**
     * 查询项目详情
     * @param id
     * @return
     */
    @Override
    public WorkXmVo getXmInfo(Long id) {
        WorkXm workXm = workXmMapper.selectWorkXmById(id);
        //转vo
        WorkXmVo workXmVo = new WorkXmVo();
        BeanUtils.copyProperties(workXm,workXmVo);
        //查询监测设计图集合
        List<WorkAccessory> workAccessories = workXmMapper.selectFile(id, "项目-监测设计图");
        int a = 0;
        for (WorkAccessory workAccessory : workAccessories) {
            workAccessory.setIndex(a);
            a ++;
        }
        workXmVo.setJcsjtList(workAccessories);
        //查询布设坐标集合
        List<WorkAccessory> workAccessories1 = workXmMapper.selectFile(id, "项目-布设坐标");
        int b = 0;
        for (WorkAccessory workAccessory : workAccessories1) {
            workAccessory.setIndex(b);
            b ++;
        }
        workXmVo.setBszbList(workAccessories1);
        //查询试油工程设计集合
        List<WorkAccessory> workAccessories2 = workXmMapper.selectFile(id, "项目-试油工程设计");
        int c = 0;
        for (WorkAccessory workAccessory : workAccessories2) {
            workAccessory.setIndex(c);
            c ++;
        }
        workXmVo.setSygcsjList(workAccessories2);
        //查询其他附件集合
        List<WorkAccessory> workAccessories3 = workXmMapper.selectFile(id, "项目-其他附件");
        int d = 0;
        for (WorkAccessory workAccessory : workAccessories3) {
            workAccessory.setIndex(d);
            d ++;
        }
        workXmVo.setQtList(workAccessories3);
        return workXmVo;
    }

    /**
     * 工作量统计(仅导出功能使用)
     * @param workXmVo
     * @return
     */
    @Override
    public List<WorkXmTjVo> getGzlTjList(WorkXmVo workXmVo) {
        //查询所有已提交的项目
        workXmVo.setTjzt("1");
        List<WorkXm> workXms = workXmMapper.selectWorkXmGzlList(workXmVo);
        //查询所有审批历史
        List<WorkXmcb> workXmcbs = workXmcbMapper.selectWorkXmcbList(new WorkXmcb());
        List<WorkXmTjVo> list = new ArrayList<>();
        for (WorkXm xm : workXms) {
            WorkXmTjVo workXmTjVo1 = new WorkXmTjVo();
            workXmTjVo1.setJh(xm.getJh());
            for (WorkXmcb workXmcb : workXmcbs) {
                if (xm.getId().equals(workXmcb.getYltzId())){
                    switch (workXmcb.getShrlx()){
                        case "0":
                            workXmTjVo1.setYltz(workXmcb.getShr());
                            break;
                        case "1":
                            workXmTjVo1.setCjsj(workXmcb.getShr());
                            break;
                        case "2":
                            workXmTjVo1.setSjsh(workXmcb.getShr());
                            break;
                        case "3":
                            workXmTjVo1.setXckc(workXmcb.getShr());
                            break;
                        default:break;
                    }
                }
            }
            list.add(workXmTjVo1);
        }
        return list;
    }

    /**
     * 查看项目工作量列表
     * @param workXmVo 项目
     * @return
     */
    @Override
    public List<WorkXm> selectWorkXmGzlList(WorkXmVo workXmVo) {
        return workXmMapper.selectWorkXmGzlList(workXmVo);
    }

    /**
     * 提交采集设计
     * @param workXm
     * @return
     */
    @Override
    public int submitCjsj(WorkXm workXm) {
        //查询项目详情
        WorkXm workXm1 = workXmMapper.selectWorkXmById(workXm.getId());
        if (workXm1.getCjtjzt().equals("0")){
            throw new ServiceException("请先填报后上传！");
        }
        //修改该项目为第三节点
        workXm.setCjtjzt("3");
        workXm.setLczt("2");
        workXm.setDqjdmc("设计审核");
        int num = workXmMapper.updateWorkXm(workXm);
        //增加审批历史
        WorkXmcb workXmcb = new WorkXmcb();
        workXmcb.setYltzId(workXm.getId());
        workXmcb.setShrId(SecurityUtils.getUserId());
        workXmcb.setShsj(DateUtils.getNowDate());
        workXmcb.setShrlx("1");
        workXmcb.setWczt("1");
        workXmcb.setCreateBy(SecurityUtils.getUsername());
        workXmcb.setCreateTime(DateUtils.getNowDate());
        workXmcbMapper.insertWorkXmcb(workXmcb);
        return num;
    }

    /**
     * 上传采集设计附件
     * @param workXmVo
     * @return
     */
    @Override
    public int updateFile(WorkXmVo workXmVo) {
        //项目id
        Long id = workXmVo.getId();
        if (StringUtils.isNull(workXmVo.getJcsjtList()) && StringUtils.isNull(workXmVo.getBszbList()) && StringUtils.isNull(workXmVo.getSygcsjList()) && StringUtils.isNull(workXmVo.getQtList())){
            throw new ServiceException("请上传附件!");
        }
        if (workXmVo.getJcsjtList().size() <= 0 && workXmVo.getBszbList().size() <= 0 &&workXmVo.getSygcsjList().size() <= 0 && workXmVo.getQtList().size() <= 0){
            throw new ServiceException("请上传附件!");
        }
        //将之前上传附件删除,重新上传
        workXmcbMapper.deleteFileByBusinessId(id,"项目-监测设计图");
        workXmcbMapper.deleteFileByBusinessId(id,"项目-布设坐标");
        workXmcbMapper.deleteFileByBusinessId(id,"项目-试油工程设计");
        workXmcbMapper.deleteFileByBusinessId(id,"项目-其他附件");

        //监测设计图集合
        List<WorkAccessory> jcsjtList = workXmVo.getJcsjtList();
        //布设坐标集合
        List<WorkAccessory> bszbList = workXmVo.getBszbList();
        //试油工程设计集合
        List<WorkAccessory> sygcsjList = workXmVo.getSygcsjList();
        //其他附件集合
        List<WorkAccessory> qtList = workXmVo.getQtList();

        if (jcsjtList.size() > 0){
            jcsjtList.forEach(list -> {
                list.setModuleName("项目-监测设计图");
            });
            insertFileList(id,jcsjtList);
        }
        if (bszbList.size() > 0){
            bszbList.forEach(list -> {
                list.setModuleName("项目-布设坐标");
            });
            insertFileList(id,bszbList);
        }
        if (sygcsjList.size() > 0){
            sygcsjList.forEach(list -> {
                list.setModuleName("项目-试油工程设计");
            });
            insertFileList(id,sygcsjList);
        }
        if (qtList.size() > 0){
            qtList.forEach(list -> {
                list.setBusinessId(id);
                list.setModuleName("项目-其他附件");

            });
            insertFileList(id,qtList);
        }
        //转实体对象
        WorkXm workXm = new WorkXm();
        workXm.setId(id);
        workXm.setCjtjzt("1");
        workXm.setUpdateBy(SecurityUtils.getUsername());
        workXm.setUpdateTime(DateUtils.getNowDate());
        return workXmMapper.updateWorkXm(workXm);
    }
    /**
     * 批量新增附件
     * @param id
     * @param list
     */
    public void insertFileList(Long id, List<WorkAccessory> list){
        list.forEach(list1 -> {
            list1.setBusinessId(id);
            list1.setCreateBy(SecurityUtils.getUsername());
            list1.setCreateTime(DateUtils.getNowDate());
        });
        workXmcbMapper.insertFile(list);
    }
}
