package com.qianhe.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.qianhe.common.core.domain.entity.SysDictData;
import com.qianhe.common.core.domain.entity.SysDictType;
import com.qianhe.common.exception.ServiceException;
import com.qianhe.common.utils.DateUtils;
import com.qianhe.common.utils.SecurityUtils;
import com.qianhe.common.utils.StringUtils;
import com.qianhe.domain.WorkAccessory;
import com.qianhe.domain.WorkXm;
import com.qianhe.mapper.WorkJdMapper;
import com.qianhe.mapper.WorkXmMapper;
import com.qianhe.system.mapper.SysDictDataMapper;
import com.qianhe.system.mapper.SysDictTypeMapper;
import com.qianhe.vo.WorkXmVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.qianhe.mapper.WorkXmcbMapper;
import com.qianhe.domain.WorkXmcb;
import com.qianhe.service.IWorkXmcbService;

/**
 * 项目从表Service业务层处理
 *
 * @author qianhe
 * @date 2024-01-17
 */
@Service
public class WorkXmcbServiceImpl implements IWorkXmcbService
{
    @Autowired
    private WorkXmcbMapper workXmcbMapper;
    @Autowired
    private WorkJdMapper workJdMapper;
    @Autowired
    private WorkXmMapper workXmMapper;
    @Autowired
    private SysDictDataMapper sysDictDataMapper;

    /**
     * 查询项目从表
     *
     * @param id 项目从表主键
     * @return 项目从表
     */
    @Override
    public WorkXmcb selectWorkXmcbById(Long id)
    {
        return workXmcbMapper.selectWorkXmcbById(id);
    }

    /**
     * 查询项目从表列表
     *
     * @param workXmcb 项目从表
     * @return 项目从表
     */
    @Override
    public List<WorkXmcb> selectWorkXmcbList(WorkXmcb workXmcb)
    {
        return workXmcbMapper.selectWorkXmcbList(workXmcb);
    }

    /**
     * 新增项目从表
     *
     * @param workXmcb 项目从表
     * @return 结果
     */
    @Override
    public int insertWorkXmcb(WorkXmcb workXmcb)
    {
        workXmcb.setCreateTime(DateUtils.getNowDate());
        return workXmcbMapper.insertWorkXmcb(workXmcb);
    }

    /**
     * 修改项目从表
     *
     * @param workXmcb 项目从表
     * @return 结果
     */
    @Override
    public int updateWorkXmcb(WorkXmcb workXmcb)
    {
        workXmcb.setUpdateTime(DateUtils.getNowDate());
        return workXmcbMapper.updateWorkXmcb(workXmcb);
    }

    /**
     * 批量删除项目从表
     *
     * @param ids 需要删除的项目从表主键
     * @return 结果
     */
    @Override
    public int deleteWorkXmcbByIds(Long[] ids)
    {
        return workXmcbMapper.deleteWorkXmcbByIds(ids);
    }

    /**
     * 删除项目从表信息
     *
     * @param id 项目从表主键
     * @return 结果
     */
    @Override
    public int deleteWorkXmcbById(Long id)
    {
        return workXmcbMapper.deleteWorkXmcbById(id);
    }



//    /**
//     * 首页-待办已办
//     * @param state
//     * @param workXmVo
//     * @return
//     */
//    @Override
//    public List<WorkXmVo> taskList(String state, WorkXmVo workXmVo) {
//        //当前登录用户id
//        Long userId = SecurityUtils.getUserId();
//        //查询当前登录用户属于哪个节点的审批人
//        List<String> jds = workJdMapper.selectJdmcByUserId(userId);
//        if (jds.size() > 0){
//            //根据节点名称和用户id查询待办已办列表
//            //查询当前登陆人待办任务
//            if (state.equals("0")){
//                userId = null;
//                return workXmcbMapper.taskList(userId, state, jds,workXmVo.getJh());
//            }else {
//                jds = null;
//                return workXmcbMapper.taskList(userId, state, jds,workXmVo.getJh());
//            }
//        }
//        return new ArrayList<>();
//    }

    @Override
    public List<WorkXmVo> taskList(Long userId, String state, List<String> jdmc, String jh) {
        return workXmcbMapper.taskList(userId,state,jdmc,jh);
    }

    /**
     * 根据项目id查询项目审批历史
     * @param id
     * @return
     */
    @Override
    public List<WorkXmcb> getspls(Long id) {
        WorkXmcb workXmcb = new WorkXmcb();
        workXmcb.setYltzId(id);
        List<WorkXmcb> workXmcbs = workXmcbMapper.selectWorkXmcbList(workXmcb);
        return workXmcbs;
    }

    /**
     * 办理审核按钮
     * @param workXmVo
     * @return
     */
    @Override
    public int handle(WorkXmVo workXmVo) {
        int i = 0;
        //判断当前节点
        switch (workXmVo.getLczt()){
            //当前节点为压裂通知
            case "0":
                i = yltz(workXmVo);
                break;
            //当前节点为采集设计
            case "1":
                i = cjsj(workXmVo);
                break;
            //当前节点为设计审核
            case "2":
                i = sjsh(workXmVo);
                break;
            //当前节点为现场勘察
            case "3":
                i = xckc(workXmVo);
                break;
            default:
                throw new ServiceException("系统错误，请联系管理员!");
        }
        return i;
    }

    /**
     * 压裂通知人操作
     */
    public int yltz(WorkXmVo workXmVo){
        WorkXm workXm = new WorkXm();
        workXm.setId(workXmVo.getId());
        workXm.setLczt("1");
        workXm.setDqjdmc("采集设计");
        int i = workXmMapper.updateWorkXm(workXm);
        //修改审批历史
        WorkXmcb workXmcb = new WorkXmcb();
        workXmcb.setId(workXmVo.getSplsId());
        workXmcb.setWczt("1");
        workXmcb.setShsj(DateUtils.getNowDate());
        workXmcbMapper.updateWorkXmcb(workXmcb);
        return i;
    }
    /**
     * 采集设计人操作
     * @param workXmVo
     * @return
     */
    public int cjsj(WorkXmVo workXmVo) {
        //项目id
        Long id = workXmVo.getId();
        if (StringUtils.isNull(workXmVo.getJcsjtList()) && StringUtils.isNull(workXmVo.getBszbList()) && StringUtils.isNull(workXmVo.getSygcsjList()) && StringUtils.isNull(workXmVo.getQtList())){
            throw new ServiceException("请上传附件!");
        }
        if (workXmVo.getJcsjtList().size() <= 0 && workXmVo.getBszbList().size() <= 0 &&workXmVo.getSygcsjList().size() <= 0 && workXmVo.getQtList().size() <= 0){
            throw new ServiceException("请上传附件!");
        }
        //将之前上传附件删除,重新上传
        workXmcbMapper.deleteFileByBusinessId(id,"项目-监测设计图");
        workXmcbMapper.deleteFileByBusinessId(id,"项目-布设坐标");
        workXmcbMapper.deleteFileByBusinessId(id,"项目-试油工程设计");
        workXmcbMapper.deleteFileByBusinessId(id,"项目-其他附件");

        //监测设计图集合
        List<WorkAccessory> jcsjtList = workXmVo.getJcsjtList();
        //布设坐标集合
        List<WorkAccessory> bszbList = workXmVo.getBszbList();
        //试油工程设计集合
        List<WorkAccessory> sygcsjList = workXmVo.getSygcsjList();
        //其他附件集合
        List<WorkAccessory> qtList = workXmVo.getQtList();

        if (jcsjtList.size() > 0){
            jcsjtList.forEach(list -> {
                list.setModuleName("项目-监测设计图");
            });
            insertFileList(id,jcsjtList);
        }
        if (bszbList.size() > 0){
            bszbList.forEach(list -> {
                list.setModuleName("项目-布设坐标");
            });
            insertFileList(id,bszbList);
        }
        if (sygcsjList.size() > 0){
            sygcsjList.forEach(list -> {
                list.setModuleName("项目-试油工程设计");
            });
            insertFileList(id,sygcsjList);
        }
        if (qtList.size() > 0){
            qtList.forEach(list -> {
                list.setBusinessId(id);
                list.setModuleName("项目-其他附件");

            });
            insertFileList(id,qtList);
        }
        //修改该项目为第三节点
        WorkXm workXm = new WorkXm();
        workXm.setId(id);
        workXm.setLczt("2");
        workXm.setDqjdmc("设计审核");
        if (StringUtils.isNotEmpty(workXmVo.getBz())){
            workXm.setBz(workXmVo.getBz());
        }
        int num = workXmMapper.updateWorkXm(workXm);
        //增加审批历史
        WorkXmcb workXmcb = new WorkXmcb();
        workXmcb.setYltzId(id);
        workXmcb.setShrId(SecurityUtils.getUserId());
        workXmcb.setShsj(DateUtils.getNowDate());
        workXmcb.setShrlx("1");
        workXmcb.setWczt("1");
        workXmcb.setCreateBy(SecurityUtils.getUsername());
        workXmcb.setCreateTime(DateUtils.getNowDate());
        workXmcbMapper.insertWorkXmcb(workXmcb);
        return num;
    }
    /**
     * 批量新增附件
     * @param id
     * @param list
     */
    public void insertFileList(Long id, List<WorkAccessory> list){
        list.forEach(list1 -> {
            list1.setBusinessId(id);
            list1.setCreateBy(SecurityUtils.getUsername());
            list1.setCreateTime(DateUtils.getNowDate());
        });
        workXmcbMapper.insertFile(list);
    }
    /**
     * 设计审核人操作
     */
    public int sjsh(WorkXmVo workXmVo){
        int num = 0;
        Long id = workXmVo.getId();
        if (StringUtils.isEmpty(workXmVo.getShzt())){
            throw new ServiceException("请选择您的审批意见!");
        }
        //查询字典键值
//        String shzt = sysDictDataMapper.selectDictLabel("shzt", workXmVo.getShzt());
        //判断审核人审核状态是否为退回
        if (workXmVo.getShzt().equals("退回")){
            //修改该项目为第2节点
            WorkXm workXm = new WorkXm();
            workXm.setId(id);
            workXm.setLczt("1");
            workXm.setDqjdmc("采集设计");
            workXm.setCjtjzt("4");
            num = workXmMapper.updateWorkXm(workXm);
            //查询项目详情
//            WorkXm workXm1 = workXmMapper.selectWorkXmById(id);
//            //增加审批历史
//            WorkXmcb workXmcb = new WorkXmcb();
//            workXmcb.setYltzId(id);
//            workXmcb.setShrId(workXm1.getTbrId());
//            workXmcb.setShrlx("0");
//            workXmcb.setWczt("0");
//            workXmcb.setSfsctj("0");
//            workXmcb.setCreateBy(SecurityUtils.getUsername());
//            workXmcb.setCreateTime(DateUtils.getNowDate());
//            workXmcbMapper.insertWorkXmcb(workXmcb);
        }else {
            //修改该项目为第四节点
            WorkXm workXm = new WorkXm();
            workXm.setId(id);
            workXm.setLczt("3");
            workXm.setDqjdmc("现场勘查");
            num = workXmMapper.updateWorkXm(workXm);
        }
        //增加审批历史
        WorkXmcb workXmcb = new WorkXmcb();
        workXmcb.setYltzId(id);
        workXmcb.setShrId(SecurityUtils.getUserId());
        workXmcb.setShsj(DateUtils.getNowDate());
        workXmcb.setShrlx("2");
        workXmcb.setShzt(workXmVo.getShzt());
        workXmcb.setWczt("1");
        if (StringUtils.isNotEmpty(workXmVo.getYj())){
            workXmcb.setYj(workXmVo.getYj());
        }
        workXmcb.setCreateBy(SecurityUtils.getUsername());
        workXmcb.setCreateTime(DateUtils.getNowDate());
        workXmcbMapper.insertWorkXmcb(workXmcb);
        return num;
    }
    /**
     * 现场勘查人操作
     */
    public int xckc(WorkXmVo workXmVo){
        int num = 0;
        Long id = workXmVo.getId();
        if (StringUtils.isEmpty(workXmVo.getShzt())){
            throw new ServiceException("请选择您的审批意见!");
        }
        //查询字典键值
//        String shzt1 = sysDictDataMapper.selectDictLabel("shzt1", workXmVo.getShzt());
        //判断审核人审核状态是否为退回
        if (workXmVo.getShzt().equals("不符合优化施工设计")){
            //修改该项目为第1节点
            WorkXm workXm = new WorkXm();
            workXm.setId(id);
            workXm.setLczt("1");
            workXm.setDqjdmc("采集设计");
            workXm.setCjtjzt("4");
            num = workXmMapper.updateWorkXm(workXm);
//            //查询项目详情
//            WorkXm workXm1 = workXmMapper.selectWorkXmById(id);
//            //增加审批历史
//            WorkXmcb workXmcb = new WorkXmcb();
//            workXmcb.setYltzId(id);
//            workXmcb.setShrId(workXm1.getTbrId());
//            workXmcb.setShrlx("0");
//            workXmcb.setWczt("0");
//            workXmcb.setSfsctj("0");
//            workXmcb.setCreateBy(SecurityUtils.getUsername());
//            workXmcb.setCreateTime(DateUtils.getNowDate());
//            workXmcbMapper.insertWorkXmcb(workXmcb);
        }else {
            //修改该项目为第五节点（暂定为已完工）
            WorkXm workXm = new WorkXm();
            workXm.setId(id);
            workXm.setLczt("4");
            workXm.setDqjdmc("已完工");
            num = workXmMapper.updateWorkXm(workXm);
        }
        //增加审批历史
        WorkXmcb workXmcb = new WorkXmcb();
        workXmcb.setYltzId(id);
        workXmcb.setShrId(SecurityUtils.getUserId());
        workXmcb.setShsj(DateUtils.getNowDate());
        workXmcb.setShrlx("3");
        workXmcb.setShzt(workXmVo.getShzt());
        workXmcb.setWczt("1");
        if (StringUtils.isNotEmpty(workXmVo.getYj())){
            workXmcb.setYj(workXmVo.getYj());
        }
        workXmcb.setCreateBy(SecurityUtils.getUsername());
        workXmcb.setCreateTime(DateUtils.getNowDate());
        workXmcbMapper.insertWorkXmcb(workXmcb);
        return num;
    }
}
